--[[------------------------------------------------------------------
--	CodeNameBlaze, an ElvUI edit by Blazeflack @ tukui.org
--
--	This file contains changes/additions to the ElvUI skinning code
------------------------------------------------------------------]]--
local E, L, V, P, G, _ = unpack(ElvUI); --Import: Engine, Locales, PrivateDB, ProfileDB, GlobalDB, Localize Underscore
local S = E:GetModule('Skins')
local CNB = E:GetModule('CodeNameBlaze')

--Cache global variables
--Lua functions
local _G = _G
local unpack, select = unpack, select

--Copied from ElvUI
local function SetModifiedBackdrop(self)
	if self.backdrop then self = self.backdrop end
	self:SetBackdropBorderColor(unpack(E["media"].rgbvaluecolor))	
end

--Copied from ElvUI
local function SetOriginalBackdrop(self)
	if self.backdrop then self = self.backdrop end
	self:SetBackdropBorderColor(unpack(E["media"].bordercolor))	
end

local buttons = {
	"UI-Panel-MinimizeButton-Disabled",
	"UI-Panel-MinimizeButton-Up",
	"UI-Panel-SmallerButton-Up",
	"UI-Panel-BiggerButton-Up",
}

local orig_HandleCloseButton = S.HandleCloseButton
--I prefer original close buttons, but desaturated. Like it used to be in ElvUI.
function S:HandleCloseButton(f, point)
	if not E.db.CNB or not E.db.CNB.skins then
		return
	end

	if E.db.CNB.skins.useOriginalCloseButton then
		for i=1, f:GetNumRegions() do
			local region = select(i, f:GetRegions())
			if region:GetObjectType() == "Texture" then
				region:SetDesaturated(1)
				for n = 1, #buttons do
					local texture = buttons[n]
					if region:GetTexture() == "Interface\\Buttons\\"..texture then
						f.originalCloseButton = true
						break
					end
				end
				if region:GetTexture() == "Interface\\DialogFrame\\UI-DialogBox-Corner" then
					region:Kill()
				end
			end
		end

		if not f.originalCloseButton then
			orig_HandleCloseButton(S, f, point)
			return
		end

		if point then
			f:Point("TOPRIGHT", point, "TOPRIGHT", 2, 2)
		end
	else
		orig_HandleCloseButton(S, f, point)
	end
end

--Set scrollbar thumb backdrop color to value color for better visibility
function CNB:HandleScrollBar(frame)
	if not frame.Thumb then
		--deprecated
		if frame:GetName() then
			if _G[frame:GetName().."ScrollUpButton"] and _G[frame:GetName().."ScrollDownButton"] then
				if frame.thumbbg and frame.thumbbg.backdropTexture then
					frame.thumbbg.backdropTexture.SetVertexColor = nil
					frame.thumbbg.backdropTexture:SetVertexColor(unpack(E.media.rgbvaluecolor))
					frame.thumbbg.backdropTexture.SetVertexColor = E.noop
				end
			end
		else
			if frame.ScrollUpButton and frame.ScrollDownButton then
				if frame.thumbbg and frame.thumbbg.backdropTexture then
					frame.thumbbg.backdropTexture.SetVertexColor = nil
					frame.thumbbg.backdropTexture:SetVertexColor(unpack(E.media.rgbvaluecolor))
					frame.thumbbg.backdropTexture.SetVertexColor = E.noop
				end
			end
		end
	else
		frame.Thumb.backdrop:SetBackdropColor(unpack(E.media.rgbvaluecolor))
	end
end
hooksecurefunc(S, "HandleScrollBar", CNB.HandleScrollBar)

--Overwrite TalkingHeadFrame skin, the backdrop looks absolutely horrible
local function LoadTalkingHeadSkin()
	if E.private.skins.blizzard.enable ~= true or E.private.skins.blizzard.talkinghead ~= true then return end
	
	TalkingHeadFrame:StripTextures()
	TalkingHeadFrame.MainFrame:StripTextures()
	TalkingHeadFrame.PortraitFrame:StripTextures()
	TalkingHeadFrame.MainFrame.Model.PortraitBg:Hide()
	S:HandleCloseButton(TalkingHeadFrame.MainFrame.CloseButton)
end

S:RegisterSkin('Blizzard_TalkingHeadUI', LoadTalkingHeadSkin)

--Skin options
local function SkinOptions()
	E.Options.args.CNB.args.config.args.skins = {
		order = 1,
		type = 'group',
		name = L["Skins"],
		args = {
			header = {
				order = 1,
				type = "header",
				name = CNB:ColorStr(L["Skins"]),
			},
			general = {
				order = 2,
				type = 'group',
				name = L["General"],
				guiInline = true,
				args = {
					useOriginalCloseButton = {
						order = 1,
						type = "toggle",
						name = L["Use Original Close Button"],
						get = function(info) return E.db.CNB.skins.useOriginalCloseButton end,
						set = function(info, value) E.db.CNB.skins.useOriginalCloseButton = value; E:StaticPopup_Show("CONFIG_RL") end,
					},
				},
			},
		},
	}
end
CNB.configs['skins'] = SkinOptions
